@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailWriter.h 441 2005-07-08 20:14:06Z svn $
+ * $Id: ThumbnailWriter.h 472 2005-07-22 04:45:50Z svn $
  *****************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -73,7 +73,7 @@ private:
     void *read(const char *file_path, apr_size_t *size);
     void calc_size(Magick::Geometry &size);
 
-    apr_pool_t * const pool_;
+    apr_pool_t *pool_;
     const char * const file_dir_;
     const char * const thumb_dir_;
 };
