@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: UploadItem.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
@@ -109,7 +109,7 @@ private:
     UploadItem(const UploadItem&);
     UploadItem &operator=(const UploadItem&);
 
-    apr_pool_t * const pool_;
+    apr_pool_t *pool_;
     const char *file_path_;
     header *header_;
 };
