@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: UploadItemList.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMLIST_H
@@ -57,23 +57,6 @@ public:
         const char *file_path;
     } item_info;
 
-    struct ItemCompare
-    {
-        bool operator()(const item_info *lhs, const item_info *rhs) const
-        {
-            return lhs->header->time > rhs->header->time;
-        }
-    };
-
-    struct ThumbnailCompare
-    {
-        bool operator()(const string& lhs, const string& rhs) const
-        {
-            return lhs > rhs;
-        }
-    };
-
-
     UploadItemList(apr_pool_t *pool,
                    const char *file_dir, const char *thumb_dir,
                    apr_size_t total_number_limit, apr_uint64_t total_size_limit);
@@ -97,6 +80,22 @@ public:
     static void dump_list(UploadItemList *item_list);
 #endif
 private:
+    struct ItemCompare
+    {
+        bool operator()(const item_info *lhs, const item_info *rhs) const
+        {
+            return lhs->header->time > rhs->header->time;
+        }
+    };
+
+    struct ThumbnailCompare
+    {
+        bool operator()(const string& lhs, const string& rhs) const
+        {
+            return lhs > rhs;
+        }
+    };
+
     typedef list<item_info *> item_list;
     typedef item_list::const_iterator item_iterator;
     typedef list<string> thumb_list;
@@ -110,7 +109,7 @@ private:
     item_iterator end();
     void remove(item_info *info);
 
-    apr_pool_t * const pool_;
+    apr_pool_t *pool_;
     const char *file_dir_;
     const char *thumb_dir_;
     const apr_size_t total_number_limit_;
