@@ -138,7 +138,7 @@ const char *RssView::time_str(apr_pool_t *pool, apr_time_t time)
     char *time_str;
     apr_size_t size;
 
-    time_str = static_cast<char *>(apr_palloc(pool, sizeof(char)*MAX_TIME_LENGTH));
+    time_str = reinterpret_cast<char *>(apr_palloc(pool, sizeof(char)*MAX_TIME_LENGTH));
 
     if (time_str == NULL) {
         throw "ɽΤΥݤ˼Ԥޤ";
