@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: TemplateExecutor.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "TemplateExecutor.h"
@@ -445,7 +445,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
                 throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
             }
             key = node->branch.right->branch.right->s_val;
-            var = static_cast<variable *>(apr_hash_get(var->h_val, key,
+            var = reinterpret_cast<variable *>(apr_hash_get(var->h_val, key,
                                                             APR_HASH_KEY_STRING));
         }
         break;
@@ -459,7 +459,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
 
         key = h->imap->at(node->branch.right->i_val);
 
-        var = static_cast<variable *>(apr_hash_get(var->h_val, key,
+        var = reinterpret_cast<variable *>(apr_hash_get(var->h_val, key,
                                                         APR_HASH_KEY_STRING));
         break;
     default:
@@ -480,7 +480,7 @@ inline TemplateExecutor::variable *TemplateExecutor::create_variable(handle *h,
 {
     if (h->variable_pool == h->variable_pool_end) {
         h->variable_pool
-            = static_cast<variable *>(apr_palloc(h->pool,
+            = reinterpret_cast<variable *>(apr_palloc(h->pool,
                                                       sizeof(variable)*VARIABLE_POOL_NUM));
         h->variable_pool_end = h->variable_pool + VARIABLE_POOL_NUM;
     }
@@ -496,7 +496,7 @@ inline TemplateExecutor::scalar *TemplateExecutor::create_scalar(handle *h,
 {
     if (h->scalar_pool == h->scalar_pool_end) {
         h->scalar_pool
-            = static_cast<scalar *>(apr_palloc(h->pool,
+            = reinterpret_cast<scalar *>(apr_palloc(h->pool,
                                                       sizeof(scalar)*SCALAR_POOL_NUM));
         h->scalar_pool_end = h->scalar_pool + SCALAR_POOL_NUM;
     }
@@ -577,14 +577,14 @@ int main(int argc, const char * const *argv)
         }
 
         if (apr_mmap_create(&file_map, fd, 0,
-                            static_cast<apr_size_t>(info.size), APR_MMAP_READ,
+                            reinterpret_cast<apr_size_t>(info.size), APR_MMAP_READ,
                             pool) != APR_SUCCESS) {
             throw "ե mmap ˼Ԥޤ";
         }
 
         TemplateLexer lexer(pool,
-                            static_cast<const char *>(file_map->mm),
-                            static_cast<apr_size_t>(info.size));
+                            reinterpret_cast<const char *>(file_map->mm),
+                            reinterpret_cast<apr_size_t>(info.size));
         TemplateParser parser(pool);
         node = parser.parse(lexer.get_token_list(), lexer.get_ident_map());
 
