@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: TemplateLexer.cpp 473 2005-07-22 13:50:06Z svn $
  *****************************************************************************/
 
 #include "TemplateLexer.h"
@@ -43,12 +43,6 @@
 #include <iomanip>
 #endif
 
-#ifdef WIN32
-#define UCHAR(c) static_cast<const unsigned char>(c)
-#else
-#define UCHAR(c) c
-#endif
-
 #ifdef DEBUG_TemplateLexer
 #define DUMP_TOKEN dump_token(&tvector_)
 #else
@@ -322,7 +316,7 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
         }
         token->type = STRING;
 
-        token->s_val = static_cast<char *>(apr_palloc(temp_pool_,
+        token->s_val = reinterpret_cast<char *>(apr_palloc(temp_pool_,
                                                       sizeof(char)*(h->input-start)));
 
         s_value = const_cast<char *>(token->s_val);
@@ -404,10 +398,10 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
         } else if (input_match(IN_STR)) {
             h->input += strlen(IN_STR);
             token->type = IN;
-        } else if (isdigit(UCHAR(*(h->input)))) {
+        } else if (isdigit(*(h->input))) {
             i_value = *(h->input++) - '0';
             while ((h->input != h->input_end) &&
-                   (isdigit(UCHAR(*(h->input))))) {
+                   (isdigit(*(h->input)))) {
                 i_value = i_value*10 + *(h->input);
                 h->input++;
             }
@@ -416,11 +410,11 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
         } else if (input_match(NOTEQUAL_STR)) {
             h->input += strlen(NOTEQUAL_STR);
             token->type = NOTEQUAL;
-        } else if (isalpha(UCHAR(*(h->input)))) {
+        } else if (isalpha(*(h->input))) {
             s_value = const_cast<char *>(h->input++);
             while ((h->input != h->input_end) &&
-                   (isalpha(UCHAR(*(h->input))) ||
-                    isdigit(UCHAR(*(h->input))) ||
+                   (isalpha(*(h->input)) ||
+                    isdigit(*(h->input)) ||
                     (*(h->input) == '_'))) {
                 h->input++;
             }
@@ -444,7 +438,7 @@ TemplateLexer::token *TemplateLexer::read_tmpl_string(handle *h)
     const char *var_end;
     token *token;
 
-    str_end = static_cast<char *>(memmem(h->input, h->input_end-h->input,
+    str_end = reinterpret_cast<char *>(memmem(h->input, h->input_end-h->input,
                                               CODE_BEGIN_STR, strlen(CODE_BEGIN_STR)));
 
     if (str_end == NULL) {
@@ -459,7 +453,7 @@ TemplateLexer::token *TemplateLexer::read_tmpl_string(handle *h)
 
     while ((h->input != str_end) &&
            ((var_start = strnchr(h->input, str_end-h->input,
-                                 UCHAR(VARIABLE_CHAR))) != NULL) &&
+                                 VARIABLE_CHAR)) != NULL) &&
            !((var_start == h->input_start) &&
              *(var_start-1) == ESCAPE_CHAR)) {
         if ((var_start+1) == str_end) {
@@ -478,7 +472,7 @@ TemplateLexer::token *TemplateLexer::read_tmpl_string(handle *h)
 
         if (*(h->input) == BRACE_LEFT_CHAR) {   //  ${ ... }׷
             if ((var_end = strnchr(h->input, str_end-h->input,
-                                   UCHAR(BRACE_RIGHT_CHAR))) == NULL) {
+                                   BRACE_RIGHT_CHAR)) == NULL) {
                 DUMP_TOKEN;
                 throw "ѿŸǤ";
             }
@@ -489,14 +483,14 @@ TemplateLexer::token *TemplateLexer::read_tmpl_string(handle *h)
             }
             h->input = var_end + 1;
         } else {                                    // $...׷
-            if (!isalpha(UCHAR(*(h->input)))) {
+            if (!isalpha(*(h->input))) {
                 DUMP_TOKEN;
                 throw "ѿ̾Ǥ";
             }
             h->input++;
             while ((h->input != h->input_end) &&
-                   (isalpha(UCHAR(*(h->input))) ||
-                    isdigit(UCHAR(*(h->input))) ||
+                   (isalpha(*(h->input)) ||
+                    isdigit(*(h->input)) ||
                     (*(h->input) == '_'))) {
                 h->input++;
             }
@@ -542,7 +536,7 @@ apr_size_t TemplateLexer::get_imap_id(const char * const start, apr_size_t lengt
     }
 
     if (id == imap_.size()) {
-        imap_.push_back(static_cast<const char *>(apr_pstrndup(pool_, start,
+        imap_.push_back(reinterpret_cast<const char *>(apr_pstrndup(pool_, start,
                                                                     length)));
     }
 
@@ -553,7 +547,7 @@ inline TemplateLexer::token *TemplateLexer::create_token(token_type type)
 {
     if (token_pool_ == token_pool_end_) {
         token_pool_
-            = static_cast<token *>(apr_palloc(temp_pool_,
+            = reinterpret_cast<token *>(apr_palloc(temp_pool_,
                                                    sizeof(token)*TOKEN_POOL_NUM));
         token_pool_end_ = token_pool_ + TOKEN_POOL_NUM;
     }
@@ -607,14 +601,14 @@ int main(int argc, const char * const *argv)
         }
 
         if (apr_mmap_create(&file_map, fd, 0,
-                            static_cast<apr_size_t>(info.size), APR_MMAP_READ,
+                            reinterpret_cast<apr_size_t>(info.size), APR_MMAP_READ,
                             pool) != APR_SUCCESS) {
             throw "ե mmap ˼Ԥޤ";
         }
 
         TemplateLexer lexer(pool,
-                            static_cast<const char *>(file_map->mm),
-                            static_cast<apr_size_t>(info.size));
+                            reinterpret_cast<const char *>(file_map->mm),
+                            reinterpret_cast<apr_size_t>(info.size));
 
         tvector = lexer.get_token_list();
         imap = lexer.get_ident_map();
