@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: UploadItem.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
@@ -139,7 +139,7 @@ const char *UploadItem::get_time()
     char *time_str;
     apr_size_t size;
 
-    time_str = static_cast<char *>(apr_palloc(pool_, sizeof(char)*MAX_TIME_LENGTH));
+    time_str = reinterpret_cast<char *>(apr_palloc(pool_, sizeof(char)*MAX_TIME_LENGTH));
 
     if (time_str == NULL) {
         throw "ɽΤΥݤ˼Ԥޤ";
@@ -157,7 +157,7 @@ void UploadItem::dump_header(header *header)
     cerr << "identifier: "      << header->identifier       << endl;
     cerr << "version: "         << header->version          << endl;
     cerr << "time: "            << header->time             << endl;
-    cerr << "file_size: "       << static_cast<unsigned int>(header->file_size) << endl;
+    cerr << "file_size: "       << reinterpret_cast<unsigned int>(header->file_size) << endl;
     cerr << "file_name: "       << header->file_name        << endl;
     cerr << "file_mime: "       << header->file_mime        << endl;
     cerr << "remove_pass: "     << header->remove_pass      << endl;
