@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemCreator.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: UploadItemCreator.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "UploadItemCreator.h"
@@ -42,7 +42,7 @@ UploadItem::header *UploadItemCreator::create_header(apr_pool_t *pool,
 
     validate_query(qmap);
 
-    data = static_cast<UploadItem::header *>(apr_pcalloc(pool,
+    data = reinterpret_cast<UploadItem::header *>(apr_pcalloc(pool,
                                                          sizeof(UploadItem::header)));
 
     strncpy(data->identifier, PACKAGE_NAME, sizeof(PACKAGE_NAME));
