@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 454 2005-07-13 20:57:51Z svn $
+ * $Id: UploadItemList.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "UploadItemList.h"
@@ -70,9 +70,9 @@ void UploadItemList::add(const char *file_path, bool is_make_thumb)
     header = reader.read(file_path, &file);
     apr_file_close(file);
 
-    info = static_cast<item_info *>(apr_palloc(pool_,
+    info = reinterpret_cast<item_info *>(apr_palloc(pool_,
                                                     sizeof(item_info)));
-    info->file_path = static_cast<const char *>(apr_pstrdup(pool_, file_path));
+    info->file_path = reinterpret_cast<const char *>(apr_pstrdup(pool_, file_path));
     info->header = header;
 
     ilist_.push_front(info);
@@ -159,7 +159,7 @@ TemplateExecutor::variable *UploadItemList::to_varray(apr_pool_t *pool,
     for (apr_size_t j = 0; (j < size) && (i != end()); j++, i++) {
         item.set_data((*i)->file_path, (*i)->header);
 
-        var = static_cast<TemplateExecutor::variable **>(apr_array_push(array));
+        var = reinterpret_cast<TemplateExecutor::variable **>(apr_array_push(array));
         *var = TemplateVariableCreator::create(pool, &item);
     }
 
@@ -181,7 +181,7 @@ TemplateExecutor::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
     }
 
     for (apr_size_t j = 0; (j < size) && (i != tlist_.end()); j++, i++) {
-         var = static_cast<TemplateExecutor::variable **>(apr_array_push(array));
+         var = reinterpret_cast<TemplateExecutor::variable **>(apr_array_push(array));
          *var = TemplateVariableCreator::create(pool, (*i).c_str());
     }
 
@@ -200,7 +200,7 @@ UploadItemList::item_info **UploadItemList::to_array(apr_pool_t *pool,
         i++;
     }
 
-    item_list = static_cast<item_info **>(apr_pcalloc(pool,
+    item_list = reinterpret_cast<item_info **>(apr_pcalloc(pool,
                                                            sizeof(item_info *)*(size+1)));
     item = item_list;
     for (apr_size_t j = 0; (j < size) && (i != end()); j++, i++) {
