@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: UploaderConfig.cpp 473 2005-07-22 13:50:06Z svn $
  *****************************************************************************/
 
 #include "UploaderConfig.h"
@@ -235,23 +235,23 @@ apr_status_t UploaderConfig::unlock()
  *****************************************************************************/
 void UploaderConfig::validate()
 {
-    if ((file_dir == NULL) ||
+    if (file_dir            == NULL) throw "FileDirectory is not specified.";
 #ifdef MAKE_THUMBNAIL
-        (thumb_dir == NULL) ||
+    if (thumb_dir           == NULL) throw "ThumbDirectory is not specified.";
 #endif
-        (tmp_dir == NULL) ||
-        (lock_dir == NULL) ||
-        (view_tmpl_path == NULL) || (download_tmpl_path == NULL) ||
-        (thumb_tmpl_path == NULL) || (error_tmpl_path == NULL)) {
-        throw "ϳ줬ޤ";
-    }
+    if (tmp_dir             == NULL) throw "TmpDirectory is not specified.";
+    if (lock_dir            == NULL) throw "LockDirectory is not specified.";
+    if (view_tmpl_path      == NULL) throw "ViewTemplateFile is not specified.";
+    if (download_tmpl_path  == NULL) throw "DownloadTemplateFile is not specified.";
+    if (thumb_tmpl_path     == NULL) throw "ThumbTemplateFile is not specified.";
+    if (error_tmpl_path     == NULL) throw "ErrorTemplateFile is not specified.";
 }
 
 #if APR_HAS_THREADS
 void UploaderConfig::init_rwlock(apr_pool_t *pool, apr_pool_t *tmp_pool)
 {
     if (apr_thread_rwlock_create(&rwlock, pool) != APR_SUCCESS) {
-        throw "åǤޤǤ";
+        throw "Can not create rwlock.";
     }
 
     apr_pool_cleanup_register(pool, rwlock, apr_pool_cleanup_null, finalize_rwlock);
@@ -352,7 +352,7 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
             throw "ƥץ졼ѤΥݤ˼Ԥޤ";
         }
 
-        TemplateLexer lexer(*tmpl_pool, static_cast<const char *>(file_map->mm),
+        TemplateLexer lexer(*tmpl_pool, reinterpret_cast<const char *>(file_map->mm),
                             static_cast<apr_size_t>(info.size));
         TemplateParser parser(*tmpl_pool);
 
@@ -392,7 +392,7 @@ apr_status_t finalize_config(void *data)
 {
     UploaderConfig *config;
 
-    config = static_cast<UploaderConfig *>(data);
+    config = reinterpret_cast<UploaderConfig *>(data);
     config->finalize();
 
     return APR_SUCCESS;
@@ -403,7 +403,7 @@ apr_status_t finalize_rwlock(void *data)
 {
     apr_thread_rwlock_t *rwlock;
 
-    rwlock = static_cast<apr_thread_rwlock_t *>(data);
+    rwlock = reinterpret_cast<apr_thread_rwlock_t *>(data);
     apr_thread_rwlock_destroy(rwlock);
 
     return APR_SUCCESS;
