@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 454 2005-07-13 20:57:51Z svn $
+ * $Id: mod_uploader.cpp 477 2005-07-23 07:16:59Z svn $
  *****************************************************************************/
 
 #include "mod_uploader.h"
@@ -47,17 +47,13 @@
 
 #define MATCH(str, pat) (strstr(str, pat) != 0)
 
-#ifdef WIN32
-#define UCHAR(c) static_cast<const unsigned char>(c)
-#else
-#define UCHAR(c) c
-#endif
-
 #undef ERROR // for Visual C++
 #ifdef DEBUG
-#define ERROR(format, str) fprintf(stderr, format, str); fputc('\n', stderr)
+#define ERROR(format, str) \
+    fprintf(stderr, format, str); fputc('\n', stderr)
 #else
-#define ERROR(format, str) ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r, format, str)
+#define ERROR(format, str) \
+    ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r, "[mod_uploader] " format, str)
 #endif
 
 static int command_handler(request_rec *r, uconfig *config, const char *arg);
@@ -306,7 +302,7 @@ int download(request_rec *r, uconfig *config, const char *arg)
         // ե̾Υå
         const char *pos = name;
 
-        while (isalnum(UCHAR(*pos)) || (*pos == '.')) {
+        while (isalnum(*pos) || (*pos == '.')) {
             pos++;
         }
 
@@ -475,7 +471,7 @@ int redirect_top(request_rec *r)
 
 uconfig *get_config(request_rec *r)
 {
-    return static_cast<uconfig *>(ap_get_module_config(r->per_dir_config,
+    return reinterpret_cast<uconfig *>(ap_get_module_config(r->per_dir_config,
                                                             &uploader_module));
 }
 
@@ -486,7 +482,7 @@ apr_table_t *get_command_table(request_rec *r)
     apr_table_t *table;
 
     table = apr_table_make(r->pool, MAX_COMMAND_NUMBER);
-    command = static_cast<char *>(apr_pcalloc(r->pool, MAX_COMMAND_LENGTH));
+    command = reinterpret_cast<char *>(apr_pcalloc(r->pool, MAX_COMMAND_LENGTH));
 
     if ((ap_setup_client_block(r, REQUEST_CHUNKED_ERROR) != OK) ||
         !ap_should_client_block(r)) {
@@ -511,10 +507,10 @@ apr_table_t *get_command_table(request_rec *r)
 
 variable *create_variable(apr_pool_t *pool, const char *str)
 {
-    variable *var = static_cast<variable *>(apr_palloc(pool,
+    variable *var = reinterpret_cast<variable *>(apr_palloc(pool,
                                                             sizeof(variable)));
     var->type = TemplateExecutor::SCALAR;
-    var->s_val = static_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
+    var->s_val = reinterpret_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
     var->s_val->type = TemplateExecutor::STRING;
     var->s_val->s_val = str;
 
@@ -523,10 +519,10 @@ variable *create_variable(apr_pool_t *pool, const char *str)
 
 variable *create_variable(apr_pool_t *pool, int i)
 {
-    variable *var = static_cast<variable *>(apr_palloc(pool,
+    variable *var = reinterpret_cast<variable *>(apr_palloc(pool,
                                                             sizeof(variable)));
     var->type = TemplateExecutor::SCALAR;
-    var->s_val = static_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
+    var->s_val = reinterpret_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
     var->s_val->type = TemplateExecutor::INTEGER;
     var->s_val->i_val = i;
 
@@ -671,10 +667,6 @@ static int uploader_handler(request_rec *r)
         // 
         config->init(r->server->process->pool, r->pool);
     } catch(const char *message) {
-        ap_rputs("<div class=\"warning\">", r);
-        ap_rputs(message, r);
-        ap_rputs("</div>", r);
-
         ERROR("Exception: %s", message);
 
         return HTTP_INTERNAL_SERVER_ERROR;
@@ -687,7 +679,7 @@ static apr_status_t finalize_dir_config(void *data)
 {
     uconfig *config;
 
-    config = static_cast<uconfig *>(data);
+    config = reinterpret_cast<uconfig *>(data);
     config->finalize();
 
     return APR_SUCCESS;
@@ -697,25 +689,28 @@ static void *create_dir_config(apr_pool_t *p, char *dirspec)
 {
     uconfig *config;
 
-    config = static_cast<uconfig *>(apr_pcalloc(p, sizeof(uconfig)));
+    config = reinterpret_cast<uconfig *>(apr_pcalloc(p, sizeof(uconfig)));
     new(config) uconfig;
 
     apr_pool_cleanup_register(p, config, finalize_dir_config, apr_pool_cleanup_null);
 
-    return static_cast<uconfig *>(config);
+    return reinterpret_cast<uconfig *>(config);
 }
 
 static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
                        apr_pool_t *ptemp, server_rec *s)
 {
+// Windows Ǥ򤹤ȥӥ̾ѤäƤޤ餷
+#ifndef WIN32
     ap_add_version_component(pconf, PACKAGE_NAME "/" PACKAGE_VERSION);
+#endif
 
     return OK;
 }
 
 static const char *set_url(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->url = apr_pstrdup(parms->pool, arg);
 
@@ -724,7 +719,7 @@ static const char *set_url(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_file_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->file_dir = apr_pstrdup(parms->pool, arg);
 
@@ -733,7 +728,7 @@ static const char *set_file_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_thumb_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->thumb_dir = apr_pstrdup(parms->pool, arg);
 
@@ -742,7 +737,7 @@ static const char *set_thumb_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_tmp_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->tmp_dir = apr_pstrdup(parms->pool, arg);
 
@@ -751,7 +746,7 @@ static const char *set_tmp_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_lock_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->lock_dir = apr_pstrdup(parms->pool, arg);
 
@@ -760,7 +755,7 @@ static const char *set_lock_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_view_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->view_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -769,7 +764,7 @@ static const char *set_view_tmpl_path(cmd_parms *parms, void *mconfig, char *arg
 
 static const char *set_download_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->download_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -778,7 +773,7 @@ static const char *set_download_tmpl_path(cmd_parms *parms, void *mconfig, char
 
 static const char *set_thumb_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->thumb_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -787,7 +782,7 @@ static const char *set_thumb_tmpl_path(cmd_parms *parms, void *mconfig, char *ar
 
 static const char *set_error_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->error_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -796,7 +791,7 @@ static const char *set_error_tmpl_path(cmd_parms *parms, void *mconfig, char *ar
 
 static const char *set_max_file_size(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->max_file_size = atoi(arg) * 1024;
 
@@ -805,7 +800,7 @@ static const char *set_max_file_size(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_total_file_size_limit(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->total_file_size_limit = atoi(arg) * 1024;
 
@@ -814,7 +809,7 @@ static const char *set_total_file_size_limit(cmd_parms *parms, void *mconfig, ch
 
 static const char *set_total_file_number_limit(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->total_file_number_limit = atoi(arg);
 
@@ -823,7 +818,7 @@ static const char *set_total_file_number_limit(cmd_parms *parms, void *mconfig,
 
 static const char *set_per_page_item_number(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = static_cast<uconfig *>(mconfig);
+    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
 
     config->per_page_item_number = atoi(arg);
 
